Skip to main contentCrate uv_resolver
Source pub use pubgrub::PubGrubHint;
- cyclonedx_json
- pubgrub
- AllowedYanks
- A set of package versions that are permitted, even if they’re marked as yanked by the
relevant index.
- ConflictingDistributionError
- An error that occurs for conflicting versions of the same package.
- DefaultResolverProvider
- The main IO backend for the resolver, which does cached requests network requests using the
[
RegistryClient] and DistributionDatabase. - DependencySelection
- Direct dependency selections from a
Lock for a named package. - DisplayResolutionGraph
- A
std::fmt::Display implementation for the resolution graph. - ExcludeNewer
- A setting that excludes files newer than a timestamp, at a global level or per-package.
- ExcludeNewerPackage
- ExcludeNewerPackageEntry
- A package-specific exclude-newer entry.
- ExcludeNewerSpan
- ExcludeNewerValueWithSpanRef
- Exclusions
- Tracks locally installed packages that should not be selected during resolution.
- FlatDistributions
- A set of
PrioritizedDist from a --find-links entry for a single package, indexed
by Version. - FlatIndex
- A set of
PrioritizedDist from a --find-links entry, indexed by PackageName
and Version. - InMemoryIndex
- In-memory index of package metadata.
- Lock
- LockError
- Manifest
- A manifest of requirements, constraints, and preferences.
- Metadata
- The full
uv workspace metadata JSON object - NoSolutionError
- A wrapper around [
pubgrub::error::NoSolutionError] that displays a resolution failure report. - NoSolutionHeader
- Options
- Options for resolving a manifest.
- OptionsBuilder
- Builder for
Options. - Package
- PackageMap
- A map from package to values, indexed by [
PackageId]. - Preference
- A pinned requirement, as extracted from a
requirements.txt file. - Preferences
- A set of pinned packages that should be preserved during resolution, if possible.
- Prerelease
- A pre-release selection policy that applies globally and to individual packages.
- PrereleasePackage
- Pre-release selection policies that apply to individual packages.
- PrereleasePackageEntry
- A package-specific pre-release selection policy.
- PylockToml
- PylockTomlError
- PythonReport
- Information about the Python interpreter in an existing environment.
- PythonRequirement
- RequirementsTxtExport
- An export of a [
Lock] that renders in requirements.txt format. - Resolver
- ResolverEnvironment
- Represents one or more marker environments for a resolution.
- ResolverManifest
- ResolverOutput
- The output of a successful resolution.
- SelectedDependency
- A direct dependency selected from a
Lock. - TreeDisplay
- UniversalMarker
- A representation of a marker for use in universal resolution.
- UpgradePackages
- The resolved set of packages that should be upgraded.
- VersionMap
- A map from versions to distributions.
- AnnotationStyle
- Indicate the style of annotation comments, used to indicate the dependencies that requested each
package.
- CanonicalLockError
- An error returned when parsing a lockfile without the general TOML fallback.
- DependencyMode
- ExcludeNewerChange
- ExcludeNewerOverride
- Whether
exclude-newer is disabled or enabled with an explicit cutoff. - ExcludeNewerOverrideChange
- ExcludeNewerPackageChange
- ExcludeNewerValue
- ExcludeNewerValueChange
- Flexibility
- Whether the
Options are configurable or fixed. - ForkStrategy
- InstallableRootKind
- Determines which dependencies are included from an install target root.
- LockParseError
- An error returned when parsing a lockfile.
- MetadataResponse
- PreferenceError
- PrereleaseMode
- PylockTomlErrorKind
- ResolutionMode
- ResolveError
- SatisfiesResult
- The result of checking if a lockfile satisfies a set of requirements.
- TreeJsonTarget
- VersionsResponse
- The response when requesting versions for a package
- Installable
- ResolverProvider
- ResolverReporter
- implicit_constraints_marker
- Return the marker domain covered by the supported environments and
requires-python. - serialize_exclude_newer_package_with_spans
- ErrorTree
- PackageVersionsResult
- WheelMetadataResult