pub fn implicit_constraints_marker(
requires_python: MarkerTree,
supported_environments: &[MarkerTree],
) -> MarkerTreeExpand description
Return the marker domain covered by the supported environments and requires-python.
pub fn implicit_constraints_marker(
requires_python: MarkerTree,
supported_environments: &[MarkerTree],
) -> MarkerTreeReturn the marker domain covered by the supported environments and requires-python.