pub struct UniversalMarker { /* private fields */ }Expand description
A representation of a marker for use in universal resolution.
(This degrades gracefully to a standard PEP 508 marker in the case of non-universal resolution.)
This universal marker is meant to combine both a PEP 508 marker and a marker for conflicting extras/groups. The latter specifically expresses whether a particular edge in a dependency graph should be followed depending on the activated extras and groups.
A universal marker evaluates to true only when both its PEP 508 marker and its conflict marker evaluate to true.
Implementations
Sourceimpl UniversalMarker
impl UniversalMarker
Sourcepub fn combined(self) -> MarkerTree
pub fn combined(self) -> MarkerTree
Returns the internal marker that combines both the PEP 508 and conflict marker.