pub trait ResolverProvider {
// Required methods
fn get_package_versions<'io>(
&'io self,
package_name: &'io PackageName,
index: Option<&'io IndexMetadata>,
) -> impl Future<Output = PackageVersionsResult> + 'io;
fn get_or_build_wheel_metadata<'io>(
&'io self,
dist: &'io Dist,
) -> impl Future<Output = WheelMetadataResult> + 'io;
fn get_installed_metadata<'io>(
&'io self,
dist: &'io InstalledDist,
) -> impl Future<Output = WheelMetadataResult> + 'io;
fn with_reporter(self, reporter: Arc<dyn Reporter>) -> Self;
}Required Methods
Sourcefn get_package_versions<'io>(
&'io self,
package_name: &'io PackageName,
index: Option<&'io IndexMetadata>,
) -> impl Future<Output = PackageVersionsResult> + 'io
fn get_package_versions<'io>( &'io self, package_name: &'io PackageName, index: Option<&'io IndexMetadata>, ) -> impl Future<Output = PackageVersionsResult> + 'io
Get the version map for a package.
Sourcefn get_or_build_wheel_metadata<'io>(
&'io self,
dist: &'io Dist,
) -> impl Future<Output = WheelMetadataResult> + 'io
fn get_or_build_wheel_metadata<'io>( &'io self, dist: &'io Dist, ) -> impl Future<Output = WheelMetadataResult> + 'io
Get the metadata for a distribution.
For a wheel, this is done by querying it (remote) metadata. For a source distribution, we (fetch and) build the source distribution and return the metadata from the built distribution.
Sourcefn get_installed_metadata<'io>(
&'io self,
dist: &'io InstalledDist,
) -> impl Future<Output = WheelMetadataResult> + 'io
fn get_installed_metadata<'io>( &'io self, dist: &'io InstalledDist, ) -> impl Future<Output = WheelMetadataResult> + 'io
Get the metadata for an installed distribution.
Sourcefn with_reporter(self, reporter: Arc<dyn Reporter>) -> Self
fn with_reporter(self, reporter: Arc<dyn Reporter>) -> Self
Set the Reporter to use for this installer.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".